# --- begin comments by J. Stolfi --------------------------
# Last edited on 1998-09-13 21:23:50 by stolfi
#
# Splitting Landini's interlinear file v1.6.
# Jorge Stolfi 12 Oct 1997
# 
# Overview
# 
#   This directory contains a copy of Gabrial Landini's interlinear
#   transcription of the Voynich manuscript, version 1.6, split
#   into "textual units".
#
# Substantive changes
# 
#   This file ("f0.S") describes the splitting process only.
#   The Voynich text proper has been edited and reformatted to
#   some extent. These changes are described in companion
#   documents ("f0.U", "f0.E").
# 
# Textual units
# 
#   A textual unit is a maximal contiguous subset of a page that 
#   has the same location code (excluding line number), and 
#   a homogeneous "text structure", which is one of:
# 
#     "parags"      
# 
#       apparently prose, in multi-line paragraphs
# 
#     "starred-parags"    
# 
#       Like parags, but with a star-like symbol 
#       in front of each paragraph.
# 
#     "itemized-parags"
# 
#       Like parags, but with a single Voynich letter or symbol 
#       in front of each paragraph.  Here the letters are indicated in
#       "{}" comments; they are also listed separately as a "letters" unit.
# 
#     "circular-lines"
# 
#       Text where each line is written around a circle
#       in some diagram. (Sometimes the starting point is not known.)
# 
#     "radial-lines"
# 
#       Text where each line is written along a ray in some diagram. 
# 
#     "titles"
# 
#       Text where each line is a title for a page or figure.
# 
#     "itemized-lines"
# 
#       The right-hand column of an itemized list ("key-like sequence")
#       where each "item" is a line of text.
# 
#     "labels"
# 
#       List of labels attached to parts of figures.
#       Also the column of words from the table in f66r (page 117).
#       Here each label is terminated by "=", and multiple
#       lines of the same label are separated by "-".
# 
#     "letters"
# 
#       The single-letter labels in itemized lists.
#       Also the column of single letters in f66r (page 117).
#       Here each letter is terminated by "=".
# 
#     "-"
#     
#       No Voynich text, only comments.
#       
#     "?"
#     
#       Unknown text structure (for untranscribed or missing pages).
# 
# Unit numbering and file names
# 
#   Each unit is stored as a separate file named "fNNN.L", where
#   "NNN" is the panel number (folio, side, and division, e.g. f85r2), 
#   and L is the location code within the page. 
#   
#   Descriptive comments that apply to a whole panel are stored in a
#   separate file named "fNNN" (without location code). Landini's
#   opening comments are stored in the file "f0.I".
#   
#   Note that it was sometimes necessary to split a page
#   with N distinct text types into more than N units, in order to 
#   preserve the ordering of the text in Landini's file. For example, the
#   transcribed "pharma" pages have blocks of normal text alternating
#   with rows of labels; each block of text and each row of labels have
#   therefore been made into a separate unit.
#   
#   Any textual unit that spans multiple panels has been 
#   assigned to the lowest-numbered of those panels.
#   
# Detailed description of files
# 
#   A detailed description of the splitting can be found in 
#   the "UNITS" file. Each line of UNITS describes one of the 
#   textual units above; it contains 8 fields separated by ":"
#   
#     * a 4-digit sequence number, which can be used to sort the
#       units in their "natural" reading order
#       
#     * the file name (fNNN or fNNN.L)
#     
#     * the apparent subject matter: "herbal", "bio", "astro", "cosmo", 
#       "pharma", "stars", "?" if unknown, or "-" if the file 
#       contains no text.
#       
#     * the "language" in Currier's sense ("A", "B", "?" if unknown, "-" if no text).
#     
#     * the "hand" ("1..5", "X", "Y", "?", or "-")
#     
#     * the type of textual unit ("parags", "labels", etc.; see list above)
#
#     * the sequential panel (page) number ("p001".. "p234"), in binding order
#       or "-" for files that are place-holders for missing folios.
#     
#     * other comments
#     
#   Any field may be followed by "?" denoting uncertainty.
#
# seqn file        section  L & H  text type        page  comments                      
# ---- ----------  -------  -----  ---------------  ----  ------------------------------
# 0001 f0.A        -        -  -   -                -     comments - overview           
# 0002 f0.I        -        -  -   -                -     comments - file format        
# 0003 f0.J        -        -  -   -                -     comments - by J. Reeds        
# 0004 f0.E        -        -  -   -                -     comments - Stolfi's edits     
# 0005 f0.S        -        -  -   -                -     comments - unit splitting     
# 0006 f0.U        -        -  -   -                -     comments - '[]' unfolding     
# 0007 f0.V        -        -  -   -                -     comments - FSG to EVA map     
# 0008 f1r         ?        A  1   -                p001  -                             
# 0009 f1r.P1      ?        A  1   parags           p001  -                             
# 0010 f1r.T1      ?        A  1   titles           p001  -                             
# 0011 f1r.P2      ?        A  1   parags           p001  -                             
# 0012 f1r.T2      ?        A  1   titles           p001  -                             
# 0013 f1r.P3      ?        A  1   parags           p001  -                             
# 0014 f1r.T3      ?        A  1   titles           p001  -                             
# 0015 f1r.P4      ?        A  1   parags           p001  -                             
# 0016 f1r.T4      ?        A  1   titles           p001  -                             
# 0017 f1v         herbal   A  1   -                p002  -                             
# 0018 f1v.P       herbal   A  1   parags           p002  -                             
# 0019 f2r         herbal   A  1   -                p003  -                             
# 0020 f2r.P       herbal   A  1   parags           p003  -                             
# 0021 f2v         herbal   A  1   -                p004  -                             
# 0022 f2v.P       herbal   A  1   parags           p004  -                             
# 0023 f3r         herbal   A  1   -                p005  -                             
# 0024 f3r.P       herbal   A  1   parags           p005  -                             
# 0025 f3v         herbal   A  1   -                p006  -                             
# 0026 f3v.P       herbal   A  1   parags           p006  -                             
# 0027 f4r         herbal   A  1   -                p007  -                             
# 0028 f4r.P       herbal   A  1   parags           p007  -                             
# 0029 f4v         herbal   A  1   -                p008  -                             
# 0030 f4v.P       herbal   A  1   parags           p008  -                             
# 0031 f5r         herbal   A  1   -                p009  -                             
# 0032 f5r.P       herbal   A  1   parags           p009  -                             
# 0033 f5v         herbal   A  1   -                p010  -                             
# 0034 f5v.P       herbal   A  1   parags           p010  -                             
# 0035 f6r         herbal   A  1   -                p011  -                             
# 0036 f6r.P       herbal   A  1   parags           p011  -                             
# 0037 f6v         herbal   A  1   -                p012  -                             
# 0038 f6v.P       herbal   A  1   parags           p012  -                             
# 0039 f7r         herbal   A  1   -                p013  -                             
# 0040 f7r.P       herbal   A  1   parags           p013  -                             
# 0041 f7v         herbal   A  1   -                p014  -                             
# 0042 f7v.P       herbal   A  1   parags           p014  -                             
# 0043 f8r         herbal   A  1   -                p015  -                             
# 0044 f8r.P1      herbal   A  1   parags           p015  -                             
# 0045 f8r.T1      herbal   A  1   titles           p015  -                             
# 0046 f8r.P2      herbal   A  1   parags           p015  -                             
# 0047 f8r.T2      herbal   A  1   titles           p015  -                             
# 0048 f8r.P3      herbal   A  1   parags           p015  -                             
# 0049 f8r.T3      herbal   A  1   titles           p015  -                             
# 0050 f8v         herbal   A  1   -                p016  -                             
# 0051 f8v.P       herbal   A  1   parags           p016  -                             
# 0052 f9r         herbal   A  1   -                p017  -                             
# 0053 f9r.P       herbal   A  1   parags           p017  -                             
# 0054 f9r.T       herbal   A  1   titles           p017  -                             
# 0055 f9v         herbal   A  1   -                p018  -                             
# 0056 f9v.P       herbal   A  1   parags           p018  -                             
# 0057 f10r        herbal   A  1   -                p019  -                             
# 0058 f10r.P      herbal   A  1   parags           p019  -                             
# 0059 f10v        herbal   A  1   -                p020  -                             
# 0060 f10v.P      herbal   A  1   parags           p020  -                             
# 0061 f11r        herbal   A  1   -                p021  -                             
# 0062 f11r.P      herbal   A  1   parags           p021  -                             
# 0063 f11v        herbal   A  1   -                p022  -                             
# 0064 f11v.P      herbal   A  1   parags           p022  -                             
# 0065 f12r        ?        ?  ?   ?                -     missing folio                 
# 0066 f12v        ?        ?  ?   ?                -     missing folio                 
# 0067 f13r        herbal   A  1   -                p023  -                             
# 0068 f13r.P      herbal   A  1   parags           p023  -                             
# 0069 f13v        herbal   A  1   -                p024  -                             
# 0070 f13v.P      herbal   A  1   parags           p024  -                             
# 0071 f14r        herbal   A  1   -                p025  -                             
# 0072 f14r.P      herbal   A  1   parags           p025  -                             
# 0073 f14v        herbal   A  1   -                p026  -                             
# 0074 f14v.P      herbal   A  1   parags           p026  -                             
# 0075 f15r        herbal   A  1   -                p027  -                             
# 0076 f15r.P      herbal   A  1   parags           p027  -                             
# 0077 f15v        herbal   A  1   -                p028  -                             
# 0078 f15v.P      herbal   A  1   parags           p028  -                             
# 0079 f16r        herbal   A  1   -                p029  -                             
# 0080 f16r.P1     herbal   A  1   parags           p029  -                             
# 0081 f16r.T1     herbal   A  1   titles           p029  -                             
# 0082 f16r.P2     herbal   A  1   parags           p029  -                             
# 0083 f16v        herbal   A  1   -                p030  -                             
# 0084 f16v.P      herbal   A  1   parags           p030  -                             
# 0085 f17r        herbal   A  1   -                p031  -                             
# 0086 f17r.P      herbal   A  1   parags           p031  -                             
# 0087 f17v        herbal   A  1   -                p032  -                             
# 0088 f17v.P      herbal   A  1   parags           p032  -                             
# 0089 f18r        herbal   A  1   -                p033  -                             
# 0090 f18r.P      herbal   A  1   parags           p033  -                             
# 0091 f18r.T      herbal   A  1   titles           p033  -                             
# 0092 f18v        herbal   A  1   -                p034  -                             
# 0093 f18v.P      herbal   A  1   parags           p034  -                             
# 0094 f19r        herbal   A  1   -                p035  -                             
# 0095 f19r.P      herbal   A  1   parags           p035  -                             
# 0096 f19v        herbal   A  1   -                p036  -                             
# 0097 f19v.P      herbal   A  1   parags           p036  -                             
# 0098 f19v.T      herbal   A  1   titles           p036  -                             
# 0099 f20r        herbal   A  1   -                p037  -                             
# 0100 f20r.P      herbal   A  1   parags           p037  -                             
# 0101 f20v        herbal   A  1   -                p038  -                             
# 0102 f20v.P      herbal   A  1   parags           p038  -                             
# 0103 f21r        herbal   A  1   -                p039  -                             
# 0104 f21r.P      herbal   A  1   parags           p039  -                             
# 0105 f21v        herbal   A  1   -                p040  -                             
# 0106 f21v.P      herbal   A  1   parags           p040  -                             
# 0107 f22r        herbal   A  1   -                p041  -                             
# 0108 f22r.P      herbal   A  1   parags           p041  -                             
# 0109 f22v        herbal   A  1   -                p042  -                             
# 0110 f22v.P      herbal   A  1   parags           p042  -                             
# 0111 f22v.T      herbal   A  1   titles           p042  -                             
# 0112 f23r        herbal   A  1   -                p043  -                             
# 0113 f23r.P      herbal   A  1   parags           p043  -                             
# 0114 f23v        herbal   A  1   -                p044  -                             
# 0115 f23v.P      herbal   A  1   parags           p044  -                             
# 0116 f24r        herbal   A  1   -                p045  -                             
# 0117 f24r.P      herbal   A  1   parags           p045  -                             
# 0118 f24r.T      herbal   A  1   titles           p045  -                             
# 0119 f24v        herbal   A  1   -                p046  -                             
# 0120 f24v.P      herbal   A  1   parags           p046  -                             
# 0121 f25r        herbal   A  1   -                p047  -                             
# 0122 f25r.P      herbal   A  1   parags           p047  -                             
# 0123 f25r.T      herbal   A  1   titles           p047  -                             
# 0124 f25v        herbal   A  1   -                p048  -                             
# 0125 f25v.P      herbal   A  1   parags           p048  -                             
# 0126 f26r        herbal   B  2   -                p049  -                             
# 0127 f26r.P      herbal   B  2   parags           p049  -                             
# 0128 f26v        herbal   B  2   -                p050  -                             
# 0129 f26v.P      herbal   B  2   parags           p050  -                             
# 0130 f27r        herbal   A  1   -                p051  -                             
# 0131 f27r.P      herbal   A  1   parags           p051  -                             
# 0132 f27r.T      herbal   A  1   titles           p051  -                             
# 0133 f27v        herbal   A  1   -                p052  -                             
# 0134 f27v.P      herbal   A  1   parags           p052  -                             
# 0135 f28r        herbal   A  1   -                p053  -                             
# 0136 f28r.P      herbal   A  1   parags           p053  -                             
# 0137 f28v        herbal   A  1   -                p054  -                             
# 0138 f28v.P1     herbal   A  1   parags           p054  -                             
# 0139 f28v.T1     herbal   A  1   titles           p054  -                             
# 0140 f28v.P2     herbal   A  1   parags           p054  -                             
# 0141 f29r        herbal   A  1   -                p055  -                             
# 0142 f29r.P      herbal   A  1   parags           p055  -                             
# 0143 f29v        herbal   A  1   -                p056  -                             
# 0144 f29v.P      herbal   A  1   parags           p056  -                             
# 0145 f30r        herbal   A  1   -                p057  -                             
# 0146 f30r.P      herbal   A  1   parags           p057  -                             
# 0147 f30v        herbal   A  1   -                p058  -                             
# 0148 f30v.P      herbal   A  1   parags           p058  -                             
# 0149 f31r        herbal   B  2   -                p059  -                             
# 0150 f31r.P      herbal   B  2   parags           p059  -                             
# 0151 f31r.T      herbal   B  2   titles           p059  -                             
# 0152 f31v        herbal   B  2   -                p060  -                             
# 0153 f31v.P      herbal   B  2   parags           p060  -                             
# 0154 f32r        herbal   A  1   -                p061  -                             
# 0155 f32r.P      herbal   A  1   parags           p061  -                             
# 0156 f32v        herbal   A  1   -                p062  -                             
# 0157 f32v.P      herbal   A  1   parags           p062  -                             
# 0158 f33r        herbal   B  2   -                p063  -                             
# 0159 f33r.P      herbal   B  2   parags           p063  -                             
# 0160 f33v        herbal   B  2   -                p064  -                             
# 0161 f33v.P      herbal   B  2   parags           p064  -                             
# 0162 f34r        herbal   B  2   -                p065  -                             
# 0163 f34r.P      herbal   B  2   parags           p065  -                             
# 0164 f34v        herbal   B  2   -                p066  -                             
# 0165 f34v.P      herbal   B  2   parags           p066  -                             
# 0166 f35r        herbal   A  1   -                p067  -                             
# 0167 f35r.P      herbal   A  1   parags           p067  -                             
# 0168 f35v        herbal   A  1   -                p068  -                             
# 0169 f35v.P      herbal   A  1   parags           p068  -                             
# 0170 f36r        herbal   A  1   -                p069  -                             
# 0171 f36r.P      herbal   A  1   parags           p069  -                             
# 0172 f36v        herbal   A  1   -                p070  -                             
# 0173 f36v.P      herbal   A  1   parags           p070  -                             
# 0174 f37r        herbal   A  1   -                p071  -                             
# 0175 f37r.P      herbal   A  1   parags           p071  -                             
# 0176 f37v        herbal   A  1   -                p072  -                             
# 0177 f37v.P      herbal   A  1   parags           p072  -                             
# 0178 f38r        herbal   A  1   -                p073  -                             
# 0179 f38r.P      herbal   A  1   parags           p073  -                             
# 0180 f38v        herbal   A  1   -                p074  -                             
# 0181 f38v.P      herbal   A  1   parags           p074  -                             
# 0182 f39r        herbal   B  2   -                p075  -                             
# 0183 f39r.P      herbal   B  2   parags           p075  -                             
# 0184 f39r.T      herbal   B  2   titles           p075  -                             
# 0185 f39v        herbal   B  2   -                p076  -                             
# 0186 f39v.P      herbal   B  2   parags           p076  -                             
# 0187 f40r        herbal   B  2   -                p077  -                             
# 0188 f40r.P      herbal   B  2   parags           p077  -                             
# 0189 f40v        herbal   B  2   -                p078  -                             
# 0190 f40v.P      herbal   B  2   parags           p078  -                             
# 0191 f40v.T      herbal   B  2   titles           p078  -                             
# 0192 f41r        herbal   B  2   -                p079  -                             
# 0193 f41r.P      herbal   B  2   parags           p079  -                             
# 0194 f41v        herbal   B  2   -                p080  -                             
# 0195 f41v.T      herbal   B  2   titles           p080  precedes paragraph            
# 0196 f41v.P      herbal   B  2   parags           p080  -                             
# 0197 f42r        herbal   A  1   -                p081  -                             
# 0198 f42r.P1     herbal   A  1   parags           p081  -                             
# 0199 f42r.T1     herbal   A  1   titles           p081  -                             
# 0200 f42r.P2     herbal   A  1   parags           p081  -                             
# 0201 f42r.T2     herbal   A  1   titles           p081  -                             
# 0202 f42r.P3     herbal   A  1   parags           p081  -                             
# 0203 f42r.T3     herbal   A  1   titles           p081  -                             
# 0204 f42v        herbal   A  1   -                p082  -                             
# 0205 f42v.P      herbal   A  1   parags           p082  -                             
# 0206 f42v.T      herbal   A  1   titles           p082  -                             
# 0207 f43r        herbal   B  2   -                p083  -                             
# 0208 f43r.P      herbal   B  2   parags           p083  -                             
# 0209 f43v        herbal   B  2   -                p084  -                             
# 0210 f43v.P      herbal   B  2   parags           p084  -                             
# 0211 f44r        herbal   A  1   -                p085  -                             
# 0212 f44r.P      herbal   A  1   parags           p085  -                             
# 0213 f44v        herbal   A  1   -                p086  -                             
# 0214 f44v.P      herbal   A  1   parags           p086  -                             
# 0215 f45r        herbal   A  1   -                p087  -                             
# 0216 f45r.P      herbal   A  1   parags           p087  -                             
# 0217 f45v        herbal   A  1   -                p088  -                             
# 0218 f45v.P      herbal   A  1   parags           p088  -                             
# 0219 f46r        herbal   B  2   -                p089  -                             
# 0220 f46r.P      herbal   B  2   parags           p089  -                             
# 0221 f46v        herbal   B  2   -                p090  -                             
# 0222 f46v.P      herbal   B  2   parags           p090  -                             
# 0223 f47r        herbal   A  1   -                p091  -                             
# 0224 f47r.P      herbal   A  1   parags           p091  -                             
# 0225 f47v        herbal   A  1   -                p092  -                             
# 0226 f47v.P      herbal   A  1   parags           p092  -                             
# 0227 f48r        herbal   B  2   -                p093  -                             
# 0228 f48r.P      herbal   B  2   parags           p093  -                             
# 0229 f48v        herbal   B  2   -                p094  -                             
# 0230 f48v.P      herbal   B  2   parags           p094  -                             
# 0231 f49r        herbal   A  1   -                p095  -                             
# 0232 f49r.P      herbal   A  1   parags           p095  -                             
# 0233 f49v        ?        A  1   -                p096  -                             
# 0234 f49v.L      ?        A  1   letters          p096  "key-like seq"                
# 0235 f49v.P      ?        A  1   itemized-lines   p096  -                             
# 0236 f50r        herbal   B  2   -                p097  -                             
# 0237 f50r.P      herbal   B  2   parags           p097  -                             
# 0238 f50v        herbal   B  2   -                p098  -                             
# 0239 f50v.P      herbal   B  2   parags           p098  -                             
# 0240 f51r        herbal   A  1   -                p099  -                             
# 0241 f51r.P      herbal   A  1   parags           p099  -                             
# 0242 f51v        herbal   A  1   -                p100  -                             
# 0243 f51v.P      herbal   A  1   parags           p100  -                             
# 0244 f52r        herbal   A  1   -                p101  -                             
# 0245 f52r.P      herbal   A  1   parags           p101  -                             
# 0246 f52v        herbal   A  1   -                p102  -                             
# 0247 f52v.P      herbal   A  1   parags           p102  -                             
# 0248 f53r        herbal   A  1   -                p103  -                             
# 0249 f53r.P      herbal   A  1   parags           p103  -                             
# 0250 f53v        herbal   A  1   -                p104  -                             
# 0251 f53v.P      herbal   A  1   parags           p104  -                             
# 0252 f54r        herbal   A  1   -                p105  -                             
# 0253 f54r.P      herbal   A  1   parags           p105  -                             
# 0254 f54v        herbal   A  1   -                p106  -                             
# 0255 f54v.P      herbal   A  1   parags           p106  -                             
# 0256 f55r        herbal   B  2   -                p107  -                             
# 0257 f55r.P      herbal   B  2   parags           p107  -                             
# 0258 f55v        herbal   B  2   -                p108  -                             
# 0259 f55v.P      herbal   B  2   parags           p108  -                             
# 0260 f56r        herbal   A  1   -                p109  -                             
# 0261 f56r.P      herbal   A  1   parags           p109  -                             
# 0262 f56v        herbal   A  1   -                p110  -                             
# 0263 f56v.P      herbal   A  1   parags           p110  -                             
# 0264 f57r        herbal   B  2   -                p111  -                             
# 0265 f57r.P      herbal   B  2   parags           p111  -                             
# 0266 f57v.T      ?        ?  ?   titles           p112                                
# 0267 f57v.R1     cosmo    ?  ?   circular-text    p112                                
# 0268 f57v.R2     cosmo    ?  ?   circular-text    p112  "key-like seq"                
# 0269 f57v.R3     cosmo    ?  ?   circular-text    p112                                
# 0270 f57v.R4     cosmo    ?  ?   circular-text    p112                                
# 0271 f57v.X      cosmo    ?  ?   labels           p112  on nymphs                     
# 0272 f57v.Y      cosmo    ?  ?   labels           p112  on directions                 
# 0273 f58r        ?        A  ?   -                p113  -                             
# 0274 f58r.P      ?        A  ?   starred-parags   p113  -                             
# 0275 f58v        ?        A  ?   -                p114  -                             
# 0276 f58v.P      ?        A  ?   parags           p114  1 star; not transcribed       
# 0277 f58v.T      ?        A  ?   titles           p114                                
# 0278 f59r        ?        ?  ?   ?                -     missing folio                 
# 0279 f59v        ?        ?  ?   ?                -     missing folio                 
# 0280 f60r        ?        ?  ?   ?                -     missing folio                 
# 0281 f60v        ?        ?  ?   ?                -     missing folio                 
# 0282 f61r        ?        ?  ?   ?                -     missing folio                 
# 0283 f61v        ?        ?  ?   ?                -     missing folio                 
# 0284 f62r        ?        ?  ?   ?                -     missing folio                 
# 0285 f62v        ?        ?  ?   ?                -     missing folio                 
# 0286 f63r        ?        ?  ?   ?                -     missing folio                 
# 0287 f63v        ?        ?  ?   ?                -     missing folio                 
# 0288 f64r        ?        ?  ?   ?                -     missing folio                 
# 0289 f64v        ?        ?  ?   ?                -     missing folio                 
# 0290 f65r        herbal   ?  ?   -                p115  -                             
# 0291 f65r.L      herbal   ?  ?   titles           p115  next to plant                 
# 0292 f65v        herbal   ?  ?   -                p116  -                             
# 0293 f65v.P      herbal   ?  ?   parags           p116  -                             
# 0294 f66r        ?        B  ?   -                p117  -                             
# 0295 f66r.L      ?        B  ?   words            p117  left col of a table           
# 0296 f66r.M      ?        B  ?   letters          p117  middle col of a table         
# 0297 f66r.W      ?        B  ?   titles           p117  above figure                  
# 0298 f66r.R      ?        B  ?   parags           p117  right col of a table?         
# 0299 f66v        herbal   B  ?   -                p118  -                             
# 0300 f66v.P      herbal   B  ?   parags           p118  -                             
# 0301 f67r1       astro    ?  ?   -                p119  -                             
# 0302 f67r1.P     astro    ?  ?   parags           p119  includes/same as 120?         
# 0303 f67r1.R1    astro    ?  ?   circular-lines   p119  -                             
# 0304 f67r1.R2    astro    ?  ?   circular-lines   p119  -                             
# 0305 f67r1.R3    astro    ?  ?   circular-lines   p119  -                             
# 0306 f67r1.S     astro    ?  ?   labels           p119  on sectors                    
# 0307 f67r2       astro    ?  ?   -                p120  -                             
# 0308 f67r2.Y     astro    ?  ?   titles           p120  sector titles                 
# 0309 f67r2.C     astro    ?  ?   parags?          p120  in sectors                    
# 0310 f67r2.L     astro    ?  ?   labels           p120  planet names?                 
# 0311 f67r2.X     astro    ?  ?   labels           p120  under moons                   
# 0312 f67r2.Z     astro    ?  ?   labels           p120  around central star           
# 0313 f67r2.P     astro    ?  ?   parags           p120  under diagram                 
# 0314 f67v2       cosmo    ?  ?   -                p121  diagram description           
# 0315 f67v2.R1    cosmo    ?  ?   circular-lines?  p121  not transcribed               
# 0316 f67v2.R2    cosmo    ?  ?   circular-lines?  p121  not transcribed               
# 0317 f67v2.R3    cosmo    ?  ?   circular-lines?  p121  not transcribed               
# 0318 f67v2.C1    cosmo    ?  ?   titles           p121  around diagram                
# 0319 f67v2.C2    cosmo    ?  ?   titles           p121  around diagram                
# 0320 f67v2.C3    cosmo    ?  ?   titles           p121  around diagram                
# 0321 f67v2.C4    cosmo    ?  ?   titles           p121  around diagram                
# 0322 f67v2.S1    cosmo    ?  ?   labels           p121  on diagram                    
# 0323 f67v2.S2    cosmo    ?  ?   labels           p121  on diagram                    
# 0324 f67v2.L1    cosmo    ?  ?   labels           p121  on diagram                    
# 0325 f67v2.L2    cosmo    ?  ?   labels           p121  on diagram                    
# 0326 f67v2.L3    cosmo    ?  ?   labels           p121  on diagram                    
# 0327 f67v2.L4    cosmo    ?  ?   labels           p121  on diagram                    
# 0328 f67v2.L5    cosmo    ?  ?   labels           p121  on diagram                    
# 0329 f67v2.L6    cosmo    ?  ?   labels           p121  on diagram                    
# 0330 f67v2.L7    cosmo    ?  ?   labels           p121  on diagram                    
# 0331 f67v2.L8    cosmo    ?  ?   labels           p121  on diagram                    
# 0332 f67v2.F1    cosmo    ?  ?   labels           p121  SE circle with faces          
# 0333 f67v2.F2    cosmo    ?  ?   labels           p121  NE circle with faces          
# 0334 f67v1       astro    ?  ?   ?                p122  not transcribed               
# 0335 f67v1.X     astro    ?  ?   labels           p122  not located                   
# 0336 f68r1       astro    ?  ?   -                p123  -                             
# 0337 f68r1.P     astro    ?  ?   parags           p123  -                             
# 0338 f68r1.S     astro    ?  ?   labels           p123  on stars                      
# 0339 f68r2       astro    ?  ?   -                p124  -                             
# 0340 f68r2.P     astro    ?  ?   parags           p124  -                             
# 0341 f68r2.U     astro    ?  ?   circular-lines   p124  unreadable                    
# 0342 f68r2.S     astro    ?  ?   labels           p124  on stars                      
# 0343 f68r2.L     astro    ?  ?   circular-lines   p124  -                             
# 0344 f68r3       astro    ?  ?   ?                p125  not transcribed               
# 0345 f68r3.X     astro    ?  ?   labels           p125  on stars                      
# 0346 f68v3       cosmo    ?  ?   -                p126  -                             
# 0347 f68v3.L     cosmo    ?  ?   labels           p126  on diagram                    
# 0348 f68v3.R     cosmo    ?  ?   labels           p126  on diagram                    
# 0349 f68v3.B     cosmo    ?  ?   parags           p126  inside diagram                
# 0350 f68v3.P     cosmo    ?  ?   parags           p126  -                             
# 0351 f68v3.I     cosmo    ?  ?   circular-lines   p126  -                             
# 0352 f68v3.O     cosmo    ?  ?   circular-lines   p126  -                             
# 0353 f68v3.S     cosmo    ?  ?   radial-lines     p126  -                             
# 0354 f68v3.X     cosmo    ?  ?   labels           p126  short logs                    
# 0355 f68v3.Y     cosmo    ?  ?   labels           p126  long logs                     
# 0356 f68v2       astro    ?  ?   -                p127  -                             
# 0357 f68v2.R     astro    ?  ?   labels           p127  radial                        
# 0358 f68v2.C     astro    ?  ?   circular-lines   p127  unknown line breaks           
# 0359 f68v2.P     astro    ?  ?   parags           p127  -                             
# 0360 f68v2.X     astro    ?  ?   labels           p127  six sectors                   
# 0361 f68v2.Y     astro    ?  ?   labels           p127  nine sectors                  
# 0362 f68v2.Z     astro    ?  ?   circular-lines   p127  outside circle                
# 0363 f68v1       astro    ?  ?   ?                p128  not transcribed               
# 0364 f68v1.X     astro    ?  ?   labels           p128  -                             
# 0365 f69r        cosmo    ?  ?   -                p129  -                             
# 0366 f69r.P      cosmo    ?  ?   parags           p129  -                             
# 0367 f69v        cosmo    ?  ?   ?                p130  not transcribed               
# 0368 f70r1       cosmo    ?  ?   ?                p131  not transcribed               
# 0369 f70r2       cosmo    ?  ?   -                p132  -                             
# 0370 f70r2.P     cosmo    ?  ?   parags           p132  -                             
# 0371 f70v2       zodiac   ?  ?   -                p133  -                             
# 0372 f70v2.C     zodiac   ?  ?   labels           p133  on central star               
# 0373 f70v2.R1    zodiac   ?  ?   circular-lines   p133  -                             
# 0374 f70v2.R2    zodiac   ?  ?   circular-lines   p133  -                             
# 0375 f70v2.R3    zodiac   ?  ?   circular-lines   p133  -                             
# 0376 f70v2.S1    zodiac   ?  ?   labels           p133  on stars                      
# 0377 f70v2.S2    zodiac   ?  ?   labels           p133  on stars                      
# 0378 f70v1       zodiac   ?  ?   -                p134  -                             
# 0379 f70v1.S     zodiac   ?  ?   labels           p134  on stars                      
# 0380 f71r        zodiac   ?  ?   -                p135  -                             
# 0381 f71r.S      zodiac   ?  ?   labels           p135  on stars                      
# 0382 f71r.R      zodiac   ?  ?   circular-lines   p135  not transcribed               
# 0383 f71v        zodiac   ?  ?   -                p136  -                             
# 0384 f71v.R1     zodiac   ?  ?   circular-lines   p136  -                             
# 0385 f71v.R2     zodiac   ?  ?   circular-lines   p136  -                             
# 0386 f71v.R3     zodiac   ?  ?   circular-lines   p136  -                             
# 0387 f71v.S1     zodiac   ?  ?   labels           p136  on stars                      
# 0388 f71v.S2     zodiac   ?  ?   labels           p136  on stars                      
# 0389 f72r1       zodiac   ?  ?   -                p137  not transcribed               
# 0390 f72r1.S     zodiac   ?  ?   labels           p137  on stars                      
# 0391 f72r1.R     zodiac   ?  ?   circular-lines   p137  not transcribed               
# 0392 f72r2       zodiac   ?  ?   -                p138  not transcribed               
# 0393 f72r2.S     zodiac   ?  ?   labels           p138  on stars                      
# 0394 f72r2.R     zodiac   ?  ?   circular-lines   p138  not transcribed               
# 0395 f72r3       zodiac   ?  ?   ?                p139  not transcribed               
# 0396 f72r3.X     zodiac   ?  ?   labels           p139  inner                         
# 0397 f72r3.Y     zodiac   ?  ?   labels           p139  middle                        
# 0398 f72r3.Z     zodiac   ?  ?   ?                p139  outer                         
# 0399 f72v3       zodiac   ?  ?   ?                p140  not transcribed               
# 0400 f72v3.X     zodiac   ?  ?   labels           p140  inner                         
# 0401 f72v3.Y     zodiac   ?  ?   labels           p140  outer                         
# 0402 f72v2       zodiac   ?  ?   ?                p141  not transcribed               
# 0403 f72v2.X     zodiac   ?  ?   labels           p141  inner                         
# 0404 f72v2.Y     zodiac   ?  ?   labels           p141  outer                         
# 0405 f72v1       zodiac   ?  ?   ?                p142  not transcribed               
# 0406 f72v1.X     zodiac   ?  ?   labels           p142  inner                         
# 0407 f72v1.Y     zodiac   ?  ?   labels           p142  outer                         
# 0408 f73r        zodiac   ?  ?   ?                p143  not transcribed               
# 0409 f73r.X      zodiac   ?  ?   labels           p143  inner                         
# 0410 f73r.Y      zodiac   ?  ?   labels           p143  outer                         
# 0411 f73r.Z      zodiac   ?  ?   labels           p143  not in circle                 
# 0412 f73v        zodiac   ?  ?   ?                p144  not transcribed               
# 0413 f73v.X      zodiac   ?  ?   labels           p144  inner                         
# 0414 f73v.Y      zodiac   ?  ?   labels           p144  outer                         
# 0415 f73v.Z      zodiac   ?  ?   labels           p144  not in circle                 
# 0416 f74r        ?        ?  ?   ?                -     missing folio                 
# 0417 f74v        ?        ?  ?   ?                -     missing folio                 
# 0418 f75r        bio      B  2   -                p145  -                             
# 0419 f75r.P      bio      B  2   parags           p145                                
# 0420 f75r.L      bio      B  2   labels           p145  on nymphs                     
# 0421 f75v        bio      B  2   -                p146  -                             
# 0422 f75v.K      bio      B  2   letters          p146  vertical letters              
# 0423 f75v.P1     bio      B  2   parags           p146  above pond                    
# 0424 f75v.L1     bio      B  2   labels           p146  top pond labels               
# 0425 f75v.P2     bio      B  2   parags           p146  between ponds                 
# 0426 f75v.L2     bio      B  2   labels           p146  bottom labels                 
# 0427 f75v.P3     bio      B  2   parags           p146  around bottom pond            
# 0428 f76r        bio      B  2   -                p147  -                             
# 0429 f76r.L      bio      B  2   letters          p147  parag labels                  
# 0430 f76r.R      bio      B  2   itemized-parags  p147  -                             
# 0431 f76v        bio      B  2   -                p148  -                             
# 0432 f76v.P      bio      B  2   parags           p148  fig labels omitted?           
# 0433 f77r        bio      B  2   -                p149  -                             
# 0434 f77r.P      bio      B  2   parags           p149  -                             
# 0435 f77r.X      bio      B  2   labels           p149  on figures                    
# 0436 f77v        bio      B  2   -                p150  -                             
# 0437 f77v.P      bio      B  2   parags           p150  -                             
# 0438 f77v.L      bio      B  2   labels           p150  on figures                    
# 0439 f78r        bio      B  2   -                p151  -                             
# 0440 f78r.P      bio      B  2   parags           p151  -                             
# 0441 f78r.X      bio      B  2   labels           p151  on figures                    
# 0442 f78v        bio      B  2   -                p152  -                             
# 0443 f78v.P      bio      B  2   parags           p152  fig labels omitted?           
# 0444 f79r        bio      B  2   -                p153  -                             
# 0445 f79r.P      bio      B  2   parags           p153  fig labels omitted?           
# 0446 f79v        bio      B  2   -                p154  -                             
# 0447 f79v.P      bio      B  2   parags           p154  fig labels omitted?           
# 0448 f80r        bio      B  2   -                p155  -                             
# 0449 f80r.P      bio      B  2   parags           p155  -                             
# 0450 f80r.X      bio      B  2   labels           p155  on figures                    
# 0451 f80v        bio      B  2   -                p156  -                             
# 0452 f80v.P      bio      B  2   parags           p156  fig labels omitted?           
# 0453 f81r        bio      B  2   -                p157  -                             
# 0454 f81r.P      bio      B  2   parags           p157  fig labels omitted?           
# 0455 f81v        bio      B  2   -                p158  -                             
# 0456 f81v.P      bio      B  2   parags           p158  -                             
# 0457 f81v.X      bio      B  2   labels           p158  on figures                    
# 0458 f82r        bio      B  2   -                p159  -                             
# 0459 f82r.P1     bio      B  2   parags           p159  -                             
# 0460 f82r.T1     bio      B  2   titles           p159  -                             
# 0461 f82r.P2     bio      B  2   parags           p159  -                             
# 0462 f82r.X      bio      B  2   labels           p159  on figures                    
# 0463 f82v        bio      B  2   -                p160  -                             
# 0464 f82v.P      bio      B  2   parags           p160  -                             
# 0465 f82v.X      bio      B  2   labels           p160  on figures                    
# 0466 f83r        bio      B  2   -                p161  -                             
# 0467 f83r.P      bio      B  2   parags           p161  -                             
# 0468 f83r.X      bio      B  2   labels           p161  on figures                    
# 0469 f83v        bio      B  2   -                p162  -                             
# 0470 f83v.P      bio      B  2   parags           p162  -                             
# 0471 f83v.X      bio      B  2   labels           p162  on figures                    
# 0472 f84r        bio      B  2   -                p163  -                             
# 0473 f84r.P      bio      B  2   parags           p163  -                             
# 0474 f84r.X      bio      B  2   labels           p163  on figures                    
# 0475 f84v        bio      B  2   -                p164  -                             
# 0476 f84v.P      bio      B  2   parags           p164  fig labels omitted?           
# 0477 f85r1       ?        B  3   -                p165  -                             
# 0478 f85r1.P     ?        B  3   parags           p165  -                             
# 0479 f85r1.T     ?        B  3   titles           p165  -                             
# 0480 f85r2       cosmo    B  3   ?                p166  nominal page 171, not transcribed 
# 0481 f85r2.T     cosmo    B  3   titles           p166                                
# 0482 f86v4       cosmo    B  3   -                p167  -                             
# 0483 f86v4.P     cosmo    B  3   parags           p167  -                             
# 0484 f86v6       ?        B  3   -                p168  -                             
# 0485 f86v6.P     ?        B  3   parags           p168  -                             
# 0486 f85v2       cosmo    B  3   ?                p169  rosette diagram, not transcribed
# 0487 f86r4       cosmo    B  3   ?                p170  rosette diagram, not transcribed
# 0488 f86r4.X1    cosmo    B  3   labels           p170  on diagram                    
# 0489 f86r4.X2    cosmo    B  3   labels           p170  on diagram                    
# 0490 f86r4.X3    cosmo    B  3   labels           p170  on diagram                    
# 0491 f86r4.X4    cosmo    B  3   labels           p170  on diagram                    
# 0492 f86r4.X5    cosmo    B  3   labels           p170  on diagram                    
# 0493 f86r4.X6    cosmo    B  3   labels           p170  on diagram                    
# 0494 f86r4.X7    cosmo    B  3   labels           p170  on diagram                    
# 0495 f86r4.X8    cosmo    B  3   labels           p170  on diagram                    
# 0496 f86r4.X9    cosmo    B  3   labels           p170  on diagram                    
# 0497 f86r4.Y1    cosmo    B  3   labels           p170  on diagram                    
# 0498 f86r4.Y2    cosmo    B  3   labels           p170  on diagram                    
# 0499 f86r4.Y3    cosmo    B  3   labels           p170  on diagram                    
# 0500 f86r4.Y4    cosmo    B  3   labels           p170  on diagram                    
# 0501 f86r4.Z1    cosmo    B  3   labels           p170  on diagram                    
# 0502 f86r4.Z2    cosmo    B  3   labels           p170  on diagram                    
# 0503 f86r4.Z3    cosmo    B  3   labels           p170  on diagram                    
# 0504 f86r4.Z4    cosmo    B  3   labels           p170  on diagram                    
# 0505 f86r4.Z5    cosmo    B  3   labels           p170  on diagram                    
# 0506 f86r4.Z6    cosmo    B  3   labels           p170  on diagram                    
# 0507 f86r6       cosmo    B  3   ?                p171  rosette diagram, not transcribed
# 0508 f85v1       cosmo    B  3   ?                p172  rosette diagram, not transcribed
# 0509 f86r3       cosmo    B  3   ?                p173  rosette diagram, not transcribed
# 0510 f86r5       cosmo    B  3   ?                p174  rosette diagram, not transcribed
# 0511 f86v5       ?        B  3   -                p175  -                             
# 0512 f86v5.P     ?        B  3   parags           p175  -                             
# 0513 f86v5.T     ?        B  3   titles           p175  -                             
# 0514 f86v3       cosmo    B  3   -                p176  -                             
# 0515 f86v3.P     cosmo    B  3   parags           p176  same as/includes 174?         
# 0516 f87r        herbal   A  4   -                p177  -                             
# 0517 f87r.P      herbal   A  4   parags           p177  -                             
# 0518 f87v        herbal   A  4   -                p178  -                             
# 0519 f87v.P      herbal   A  4   parags           p178  -                             
# 0520 f88r        pharma   A  4   -                p179  -                             
# 0521 f88r.t      pharma   A  4   labels           p179  under plants                  
# 0522 f88r.P1     pharma   A  4   parags           p179  -                             
# 0523 f88r.m      pharma   A  4   labels           p179  under plants                  
# 0524 f88r.P2     pharma   A  4   parags           p179  -                             
# 0525 f88r.b      pharma   A  4   labels           p179  under plants                  
# 0526 f88r.P3     pharma   A  4   parags           p179  -                             
# 0527 f88v        pharma   A  4   -                p180  -                             
# 0528 f88v.t      pharma   A  4   labels           p180  under plants                  
# 0529 f88v.P1     pharma   A  4   parags           p180  -                             
# 0530 f88v.m      pharma   A  4   labels           p180  under plants                  
# 0531 f88v.P2     pharma   A  4   parags           p180  -                             
# 0532 f88v.b      pharma   A  4   labels           p180  under plants                  
# 0533 f89r1       pharma   A  ?   -                p181  -                             
# 0534 f89r1.t     pharma   A  ?   labels           p181  under plants                  
# 0535 f89r1.P1    pharma   A  ?   parags           p181  -                             
# 0536 f89r1.m     pharma   A  ?   labels           p181  under plants                  
# 0537 f89r1.P2    pharma   A  ?   parags           p181  -                             
# 0538 f89r1.b     pharma   A  ?   labels           p181  under plants                  
# 0539 f89r2       pharma   A  ?   -                p182  includes f89r3                
# 0540 f89r2.t     pharma   A  ?   labels           p182  under plants                  
# 0541 f89r2.P1    pharma   A  ?   parags           p182  -                             
# 0542 f89r2.m1    pharma   A  ?   labels           p182  under plants                  
# 0543 f89r2.P2    pharma   A  ?   parags           p182  -                             
# 0544 f89r2.m2    pharma   A  ?   labels           p182  under plants                  
# 0545 f89r2.P3    pharma   A  ?   parags           p182  -                             
# 0546 f89r2.b     pharma   A  ?   labels           p182  under plants                  
# 0547 f89v2       pharma   A  ?   -                p183  includes f89v3                
# 0548 f89v2.t     pharma   A  ?   labels           p183  under plants                  
# 0549 f89v2.P1    pharma   A  ?   parags           p183  -                             
# 0550 f89v2.m     pharma   A  ?   labels           p183  under plants                  
# 0551 f89v2.P2    pharma   A  ?   parags           p183  -                             
# 0552 f89v2.b     pharma   A  ?   labels           p183  under plants                  
# 0553 f89v2.X     pharma   A  ?   labels           p183  by Grove, not located         
# 0554 f89v2.Y     pharma   A  ?   labels           p183  by Grove, not located         
# 0555 f89v1       pharma   A  ?   -                p184  -                             
# 0556 f89v1.t     pharma   A  ?   labels           p184  under plants                  
# 0557 f89v1.P1    pharma   A  ?   parags           p184  -                             
# 0558 f89v1.b     pharma   A  ?   labels           p184  under plants                  
# 0559 f89v1.X     pharma   A  ?   labels           p184  by Grove, not located         
# 0560 f90r1       herbal   A  ?   -                p185  -                             
# 0561 f90r1.P     herbal   A  ?   parags           p185  -                             
# 0562 f90r2       herbal   A  ?   -                p186  -                             
# 0563 f90r2.P     herbal   A  ?   parags           p186  -                             
# 0564 f90v2       herbal   A  ?   -                p187  -                             
# 0565 f90v2.P     herbal   A  ?   parags           p187  -                             
# 0566 f90v1       herbal   A  ?   -                p188  -                             
# 0567 f90v1.P     herbal   A  ?   parags           p188  -                             
# 0568 f91r        ?        ?  ?   ?                -     missing folios                
# 0569 f91v        ?        ?  ?   ?                -     missing folios                
# 0570 f92r        ?        ?  ?   ?                -     missing folios                
# 0571 f92v        ?        ?  ?   ?                -     missing folios                
# 0572 f93r        herbal   A  4   -                p189  -                             
# 0573 f93r.P      herbal   A  4   parags           p189  -                             
# 0574 f93v        herbal   A  4   -                p190  -                             
# 0575 f93v.P      herbal   A  4   parags           p190  -                             
# 0576 f94r        herbal   B  5   -                p191  -                             
# 0577 f94r.P      herbal   B  5   parags           p191  -                             
# 0578 f94r.T      herbal   B  5   titles           p191  -                             
# 0579 f94v        herbal   B  5   -                p192  -                             
# 0580 f94v.P      herbal   B  5   parags           p192  -                             
# 0581 f95r1       herbal   B  5   -                p193  -                             
# 0582 f95r1.P     herbal   B  5   parags           p193  -                             
# 0583 f95r2       herbal   B  5   -                p194  -                             
# 0584 f95r2.P     herbal   B  5   parags           p194  -                             
# 0585 f95v2       herbal   B  5   -                p195  -                             
# 0586 f95v2.P     herbal   B  5   parags           p195  -                             
# 0587 f95v1       herbal   B  5   -                p196  -                             
# 0588 f95v1.P     herbal   B  5   parags           p196  -                             
# 0589 f96r        herbal   A  4   -                p197  -                             
# 0590 f96r.P      herbal   A  4   parags           p197  -                             
# 0591 f96v        herbal   A  4   -                p198  -                             
# 0592 f96v.P      herbal   A  4   parags           p198  -                             
# 0593 f97r        ?        ?  ?   ?                -     missing folios                
# 0594 f97v        ?        ?  ?   ?                -     missing folios                
# 0595 f98r        ?        ?  ?   ?                -     missing folios                
# 0596 f98v        ?        ?  ?   ?                -     missing folios                
# 0597 f99r        pharma   A  ?   -                p199  -                             
# 0598 f99r.P      pharma   A  ?   parags           p199  -                             
# 0599 f99r.X      pharma   A  ?   labels           p199  by Grove, not located         
# 0600 f99v        pharma   A  ?   -                p200  -                             
# 0601 f99v.P      pharma   A  ?   parags           p200  -                             
# 0602 f99v.X      pharma   A  ?   labels           p200  by Grove, not located         
# 0603 f100r       pharma   A  ?   -                p201  -                             
# 0604 f100r.t     pharma   A  ?   labels           p201  under plants                  
# 0605 f100r.m     pharma   A  ?   labels           p201  under plants                  
# 0606 f100r.P1    pharma   A  ?   parags           p201  -                             
# 0607 f100r.b     pharma   A  ?   labels           p201  under plants                  
# 0608 f100r.P2    pharma   A  ?   parags           p201  -                             
# 0609 f100v       pharma   A  ?   -                p202  -                             
# 0610 f100v.T     pharma   A  ?   labels           p202  under plants                  
# 0611 f100v.M     pharma   A  ?   labels           p202  under plants                  
# 0612 f100v.B     pharma   A  ?   labels           p202  under plants                  
# 0613 f100v.P     pharma   A  ?   parags           p202  -                             
# 0614 f101r1      pharma   A  ?   -                p203  -                             
# 0615 f101r1.P    pharma   A  ?   parags           p203  -                             
# 0616 f101r2      pharma   ?  ?   -                p204  -                             
# 0617 f101v2      pharma   A  ?   -                p205  -                             
# 0618 f101v2.P    pharma   A  ?   parags           p205  -                             
# 0619 f101v2.T    pharma   A  ?   titles           p205  -                             
# 0620 f101v2.X    pharma   A  ?   labels           p205  by Grove, not located         
# 0621 f101v1      pharma   A  ?   -                p206  -                             
# 0622 f101v1.R1   pharma   A  ?   labels           p206  under plants                  
# 0623 f101v1.R2   pharma   A  ?   labels           p206  under plants                  
# 0624 f101v1.P    pharma   A  ?   parags           p206  -                             
# 0625 f101v1.T    pharma   A  ?   titles           p206  -                             
# 0626 f102r1      pharma   A  ?   -                p207  -                             
# 0627 f102r1.L1   pharma   A  ?   labels           p207  -                             
# 0628 f102r1.P    pharma   A  ?   parags           p207  -                             
# 0629 f102r2      pharma   A  ?   -                p208  -                             
# 0630 f102r2.P    pharma   A  ?   parags           p208  -                             
# 0631 f102r2.X    pharma   A  ?   labels           p208  on plants                     
# 0632 f102v2      pharma   A  ?   -                p209  -                             
# 0633 f102v2.C    pharma   A  ?   labels           p209  on containers                 
# 0634 f102v2.L1   pharma   A  ?   labels           p209  on plants                     
# 0635 f102v2.L2   pharma   A  ?   labels           p209  on plants                     
# 0636 f102v2.P1   pharma   A  ?   parags           p209  -                             
# 0637 f102v2.L3   pharma   A  ?   labels           p209  on plants                     
# 0638 f102v2.P2   pharma   A  ?   parags           p209  -                             
# 0639 f102v1      pharma   A  ?   -                p210  -                             
# 0640 f102v1.L1   pharma   A  ?   labels           p210  on plants                     
# 0641 f102v1.P1   pharma   A  ?   parags           p210  -                             
# 0642 f102v1.L2   pharma   A  ?   labels           p210  on plants                     
# 0643 f102v1.P2   pharma   A  ?   parags           p210  -                             
# 0644 f103r       stars    B  X   -                p211  -                             
# 0645 f103r.P     stars    B  X   starred-parags   p211  -                             
# 0646 f103v       stars    B  X   -                p212  -                             
# 0647 f103v.P     stars    B  X   starred-parags   p212  -                             
# 0648 f104r       stars    B  X   -                p213  -                             
# 0649 f104r.P     stars    B  X   starred-parags   p213  -                             
# 0650 f104v       stars    B  X   -                p214  -                             
# 0651 f104v.P     stars    B  X   starred-parags   p214  -                             
# 0652 f105r       stars    B  Y   -                p215  -                             
# 0653 f105r.P1    stars    B  Y   starred-parags   p215  -                             
# 0654 f105r.T1    stars    B  Y   titles           p215  -                             
# 0655 f105r.P2    stars    B  Y   starred-parags   p215  -                             
# 0656 f105r.T2    stars    B  Y   titles           p215  -                             
# 0657 f105v       stars    B  Y   -                p216  -                             
# 0658 f105v.P     stars    B  Y   starred-parags   p216  -                             
# 0659 f106r       stars    B  X   -                p217  -                             
# 0660 f106r.P     stars    B  X   starred-parags   p217  -                             
# 0661 f106v       stars    B  X   -                p218  -                             
# 0662 f106v.P     stars    B  X   starred-parags   p218  -                             
# 0663 f107r       stars    B  ?   -                p219  -                             
# 0664 f107r.P     stars    B  ?   starred-parags   p219  -                             
# 0665 f107v       stars    B  ?   -                p220  -                             
# 0666 f107v.P     stars    B  ?   starred-parags   p220  -                             
# 0667 f108r       stars    B  ?   -                p221  -                             
# 0668 f108r.P     stars    B  ?   starred-parags   p221  -                             
# 0669 f108v       stars    B  ?   -                p222  -                             
# 0670 f108v.P     stars    B  ?   starred-parags   p222  -                             
# 0671 f108v.T     stars    B  ?   titles           p222  -                             
# 0672 f109r       ?        ?  ?   ?                -     missing folios                
# 0673 f109v       ?        ?  ?   ?                -     missing folios                
# 0674 f110r       ?        ?  ?   ?                -     missing folios                
# 0675 f110v       ?        ?  ?   ?                -     missing folios                
# 0676 f111r       stars    B  ?   -                p223  -                             
# 0677 f111r.P     stars    B  ?   starred-parags   p223  -                             
# 0678 f111v       stars    B  ?   -                p224  -                             
# 0679 f111v.P     stars    B  ?   starred-parags   p224  -                             
# 0680 f112r       stars    B  ?   -                p225  -                             
# 0681 f112r.P     stars    B  ?   starred-parags   p225  -                             
# 0682 f112v       stars    B  ?   -                p226  -                             
# 0683 f112v.P     stars    B  ?   starred-parags   p226  -                             
# 0684 f113r       stars    B  ?   -                p227  -                             
# 0685 f113r.P     stars    B  ?   starred-parags   p227  -                             
# 0686 f113v       stars    B  ?   -                p228  -                             
# 0687 f113v.P     stars    B  ?   starred-parags   p228  -                             
# 0688 f114r       stars    B  ?   -                p229  -                             
# 0689 f114r.P1    stars    B  ?   starred-parags   p229  -                             
# 0690 f114r.T1    stars    B  ?   titles           p229  -                             
# 0691 f114r.P2    stars    B  ?   starred-parags   p229  -                             
# 0692 f114v       stars    B  ?   -                p230  -                             
# 0693 f114v.P     stars    B  ?   starred-parags   p230  -                             
# 0694 f115r       stars    B  ?   -                p231  -                             
# 0695 f115r.P     stars    B  ?   starred-parags   p231  -                             
# 0696 f115v       stars    B  ?   -                p232  -                             
# 0697 f115v.P     stars    B  ?   starred-parags   p232  -                             
# 0698 f116r       stars    B  ?   -                p233  -                             
# 0699 f116r.P     stars    B  ?   starred-parags   p233  -                             
# 0700 f116v       ?        ?  ?   -                p234  -                             
# 0701 f116v.P     ?        ?  ?   parags           p234  "michiton" text               
#
# --- end comments by J. Stolfi ----------------------------
